diff -w -ru gnome-vfs-1.0.3.orig/configure gnome-vfs-1.0.3/configure
--- gnome-vfs-1.0.3.orig/configure	Fri Oct 12 03:35:44 2001
+++ gnome-vfs-1.0.3/configure	Thu Oct 25 13:13:36 2001
@@ -8027,7 +8027,8 @@
   cat conftest.$ac_ext >&5
   rm -rf conftest*
   CATOBJEXT=.mo
-		   DATADIRNAME=lib
+#		   DATADIRNAME=lib
+		   DATADIRNAME=share
 fi
 rm -f conftest*
 		INSTOBJEXT=.mo
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-directory-filter.h gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-directory-filter.h
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-directory-filter.h	Sat Jul 21 00:40:32 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-directory-filter.h	Thu Oct 25 15:41:12 2001
@@ -48,7 +48,7 @@
 	GNOME_VFS_DIRECTORY_FILTER_NEEDS_NAME = 1 << 0,
 	GNOME_VFS_DIRECTORY_FILTER_NEEDS_TYPE = 1 << 1,
 	GNOME_VFS_DIRECTORY_FILTER_NEEDS_STAT = 1 << 2,
-	GNOME_VFS_DIRECTORY_FILTER_NEEDS_MIMETYPE = 1 << 3,
+	GNOME_VFS_DIRECTORY_FILTER_NEEDS_MIMETYPE = 1 << 3
 } GnomeVFSDirectoryFilterNeeds;
 
 typedef enum {
@@ -76,7 +76,7 @@
 	gnome_vfs_directory_filter_new_custom
 					(GnomeVFSDirectoryFilterFunc func,
 					 GnomeVFSDirectoryFilterNeeds needs,
-					 gpointer func_data);
+					 gpointer funcdata);
 void	gnome_vfs_directory_filter_destroy
 					(GnomeVFSDirectoryFilter *filter);
 gboolean
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-file-info.h gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-file-info.h
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-file-info.h	Sat Jul 21 00:40:33 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-file-info.h	Thu Oct 25 15:31:40 2001
@@ -38,7 +38,7 @@
 	/* Whether the file is a symlink.  */
 	GNOME_VFS_FILE_FLAGS_SYMLINK = 1 << 0,
 	/* Whether the file is on a local file system.  */
-	GNOME_VFS_FILE_FLAGS_LOCAL = 1 << 1,
+	GNOME_VFS_FILE_FLAGS_LOCAL = 1 << 1
 } GnomeVFSFileFlags;
 
 /* Flags indicating what fields in a GnomeVFSFileInfo struct are valid. 
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-inet-connection.c gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-inet-connection.c
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-inet-connection.c	Sat Jul 21 00:40:33 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-inet-connection.c	Thu Oct 25 12:32:15 2001
@@ -35,7 +35,9 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+#ifndef _AIX
 extern int h_errno;
+#endif
 
 
 struct GnomeVFSInetConnection {
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-private-utils.h gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-private-utils.h
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-private-utils.h	Sat Jul 21 00:40:33 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-private-utils.h	Thu Oct 25 15:26:24 2001
@@ -41,7 +41,7 @@
 					 GnomeVFSProcessOptions options,
 					 GnomeVFSProcessInitFunc init_func,
 					 gpointer data);
-GnomeVFSProcessRunResult
+GnomeVFSProcessResult
 	 	gnome_vfs_process_run_cancellable
 					(const gchar *file_name,
 					 const gchar * const argv[],
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-process.c gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-process.c
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-process.c	Sat Jul 21 00:40:33 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-process.c	Thu Oct 25 15:27:18 2001
@@ -258,7 +258,7 @@
  * 
  * Return value: A numeric value reporting the result of the operation.
  **/
-GnomeVFSProcessRunResult
+GnomeVFSProcessResult
 gnome_vfs_process_signal (GnomeVFSProcess *process,
 			  guint signal_number)
 {
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-result.c gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-result.c
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-result.c	Sat Jul 21 00:40:33 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-result.c	Thu Oct 25 12:42:13 2001
@@ -31,7 +31,9 @@
 #include "gnome-vfs-private.h"
 
 
+#ifndef _AIX
 extern int h_errno;
+#endif
 
 
 static gchar *status_strings[] = {
@@ -99,7 +101,9 @@
 	case EMFILE:	return GNOME_VFS_ERROR_TOO_MANY_OPEN_FILES;
 	case EMLINK:	return GNOME_VFS_ERROR_TOO_MANY_LINKS;
 	case ENFILE:	return GNOME_VFS_ERROR_TOO_MANY_OPEN_FILES;
+#if !(ENOTEMPTY == EEXIST)
 	case ENOTEMPTY: return GNOME_VFS_ERROR_DIRECTORY_NOT_EMPTY;
+#endif
 	case ENOENT:	return GNOME_VFS_ERROR_NOT_FOUND;
 	case ENOMEM:	return GNOME_VFS_ERROR_NO_MEMORY;
 	case ENOSPC:	return GNOME_VFS_ERROR_NO_SPACE;
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-seekable.c gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-seekable.c
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-seekable.c	Sat Jul 21 00:40:33 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-seekable.c	Thu Oct 25 15:28:38 2001
@@ -135,7 +135,7 @@
 			return GNOME_VFS_ERROR_NO_SPACE;
 		
 	} while (blk_read > 0);
-	//} while (blk_read == BLK_SIZE);
+	/*} while (blk_read == BLK_SIZE); */
 
 	result = gnome_vfs_seek (mh->tmp_file, GNOME_VFS_SEEK_START, 0);
 
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-xfer.h gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-xfer.h
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-xfer.h	Sat Jul 21 00:40:35 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-xfer.h	Thu Oct 25 15:32:58 2001
@@ -75,7 +75,7 @@
 	GNOME_VFS_XFER_OVERWRITE_ACTION_REPLACE = 1,
 	GNOME_VFS_XFER_OVERWRITE_ACTION_REPLACE_ALL = 2,
 	GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP = 3,
-	GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP_ALL = 4,
+	GNOME_VFS_XFER_OVERWRITE_ACTION_SKIP_ALL = 4
 } GnomeVFSXferOverwriteAction;
 
 typedef enum {
@@ -84,7 +84,7 @@
 	GNOME_VFS_XFER_ERROR_MODE_ABORT = 0,
 	/* Invoke the progress callback with a
 	   `GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR' status code. */
-	GNOME_VFS_XFER_ERROR_MODE_QUERY = 1,
+	GNOME_VFS_XFER_ERROR_MODE_QUERY = 1
 } GnomeVFSXferErrorMode;
 
 /* This defines the possible actions to be performed after an error has
diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs-pthread/gnome-vfs-job-slave.c gnome-vfs-1.0.3/libgnomevfs-pthread/gnome-vfs-job-slave.c
--- gnome-vfs-1.0.3.orig/libgnomevfs-pthread/gnome-vfs-job-slave.c	Sat Feb  3 21:54:14 2001
+++ gnome-vfs-1.0.3/libgnomevfs-pthread/gnome-vfs-job-slave.c	Thu Oct 25 13:03:16 2001
@@ -31,6 +31,10 @@
 #include "gnome-vfs-private.h"
 #include "gnome-vfs-thread-pool.h"
 #include "gnome-vfs.h"
+#ifdef func_data
+/* On AIX func_data is a #define in sys/timer.h */
+#undef func_data
+#endif
 #include <gtk/gtk.h>
 #include <pthread.h>
 #include <unistd.h>
diff -w -ru gnome-vfs-1.0.3.orig/modules/bzip2-method.c gnome-vfs-1.0.3/modules/bzip2-method.c
--- gnome-vfs-1.0.3.orig/modules/bzip2-method.c	Sat Jul 21 00:40:36 2001
+++ gnome-vfs-1.0.3/modules/bzip2-method.c	Thu Oct 25 15:43:32 2001
@@ -547,7 +547,7 @@
 			file_info->name[namelen-4] = '\0';
 
 		/* we can't tell the size without uncompressing it */
-		//file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;
+		/*file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;*/
 
 		/* guess the mime type of the file inside */
 		/* FIXME bugzilla.eazel.com 2791: guess mime based on contents */
diff -w -ru gnome-vfs-1.0.3.orig/modules/extfs-method.c gnome-vfs-1.0.3/modules/extfs-method.c
--- gnome-vfs-1.0.3.orig/modules/extfs-method.c	Tue Jan 30 13:17:46 2001
+++ gnome-vfs-1.0.3/modules/extfs-method.c	Thu Oct 25 15:44:35 2001
@@ -189,8 +189,8 @@
 get_dirname (const gchar *pth)
 {
 	gchar *p;
-	//gchar *s;
-	//guint len;
+	/*gchar *s;*/
+	/*guint len;*/
 	gchar *path = strip_separators(pth);
 
 	p = strrchr (path, G_DIR_SEPARATOR);
@@ -586,8 +586,8 @@
 	gchar *quoted_file_name;
 	gchar *cmd;
 	gchar *sub_uri;
-	//const gchar *p;
-	//const GList *item;
+	/*const gchar *p;*/
+	/*const GList *item;*/
 	GList *entries=NULL;
 	GList *l;
 	FILE *pipe;
@@ -712,7 +712,7 @@
 
 	gnome_vfs_file_info_copy (file_info, (GnomeVFSFileInfo *)item->data);
 
-	//gnome_vfs_file_info_unref((GnomeVFSFileInfo *)item->data);
+	/*gnome_vfs_file_info_unref((GnomeVFSFileInfo *)item->data);*/
 
 	*((GList **)method_handle) = item->next;
 
diff -w -ru gnome-vfs-1.0.3.orig/modules/ftp-method.c gnome-vfs-1.0.3/modules/ftp-method.c
--- gnome-vfs-1.0.3.orig/modules/ftp-method.c	Mon Aug 13 21:21:41 2001
+++ gnome-vfs-1.0.3/modules/ftp-method.c	Mon Oct 29 09:56:47 2001
@@ -986,7 +986,7 @@
 	/* FIXME bugzilla.eazel.com 1463 */
 	GnomeVFSResult result;
 	GnomeVFSFileSize num_bytes = 1024, bytes_read;
-	gchar buffer[num_bytes+1];
+	gchar buffer[/* num_bytes */ 1024+1];
 
 	result = ftp_connection_acquire(uri, &conn);
 	if (result != GNOME_VFS_OK) {
@@ -1132,7 +1132,7 @@
 	FtpConnection *conn;
 	GnomeVFSResult result;
 	GnomeVFSFileSize num_bytes = 1024, bytes_read;
-	gchar buffer[num_bytes+1];
+	gchar buffer[/* num_bytes */ 1024+1];
 	GString *dirlist = g_string_new ("");
 
 	result = ftp_connection_acquire (uri, &conn, context);
diff -w -ru gnome-vfs-1.0.3.orig/modules/gzip-method.c gnome-vfs-1.0.3/modules/gzip-method.c
--- gnome-vfs-1.0.3.orig/modules/gzip-method.c	Sat Jul 21 00:40:36 2001
+++ gnome-vfs-1.0.3/modules/gzip-method.c	Thu Oct 25 15:46:43 2001
@@ -737,7 +737,7 @@
 			file_info->name[namelen-3] = '\0';
 
 		/* we can't tell the size without uncompressing it */
-		//file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;
+		/*file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;*/
 
 		/* guess the mime type of the file inside */
 		/* FIXME bugzilla.eazel.com 2791: guess mime based on contents */
diff -w -ru gnome-vfs-1.0.3.orig/modules/test-method.c gnome-vfs-1.0.3/modules/test-method.c
--- gnome-vfs-1.0.3.orig/modules/test-method.c	Fri Mar 23 18:42:37 2001
+++ gnome-vfs-1.0.3/modules/test-method.c	Thu Oct 25 15:47:00 2001
@@ -578,7 +578,7 @@
 	
 	if (load_settings (PREFIX "/etc/vfs/Test-conf.xml") == FALSE) {
 
-	  // FIXME: we probably shouldn't use printf to output the message
+	  /* FIXME: we probably shouldn't use printf to output the message*/
 	  printf (_("Didn't find a valid settings file at %s\n"), 
 		  PREFIX "/etc/vfs/Test-conf.xml");
 	  properly_initialized = FALSE;

diff -w -ru gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-directory-filter.c gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-directory-filter.c
--- gnome-vfs-1.0.3.orig/libgnomevfs/gnome-vfs-directory-filter.c	Sat Jul 21 00:40:32 2001
+++ gnome-vfs-1.0.3/libgnomevfs/gnome-vfs-directory-filter.c	Thu Oct 25 12:57:23 2001
@@ -151,10 +151,10 @@
  * not
  * @needs: Bitmask representing the information that @func needs to decide
  * if a file passes through the filter or not.
  * @func_data: Additional data to be passed to @func
  * 
  * Create a new custom directory filter.  Whenever the filter is applied, @func
  * will be called with info about the file to be filtered and @func_data as
  * parameters.  If @func returns %TRUE, the file passes the filter; if it
  * returns %FALSE, it does not.
  * 
@@ -163,7 +163,7 @@
 GnomeVFSDirectoryFilter *
 gnome_vfs_directory_filter_new_custom (GnomeVFSDirectoryFilterFunc func,
 				       GnomeVFSDirectoryFilterNeeds needs,
-				       gpointer func_data)
+				       gpointer funcdata)
 {
 	GnomeVFSDirectoryFilter *new;
 
@@ -174,7 +174,7 @@
 	new->pattern = NULL;
 
 	new->func = func;
-	new->data = func_data;
+	new->data = funcdata;
 	new->needs = needs;
 
 	return new;
@@ -151,10 +151,10 @@
  * @needs: Bitmask representing the information that @func needs to decide
  * if a file passes through the filter or not.
- * @func_data: Additional data to be passed to @func
+ * @funcdata: Additional data to be passed to @func
  * 
  * Create a new custom directory filter.  Whenever the filter is applied, @func
@@ -151,10 +151,10 @@
  * 
  * Create a new custom directory filter.  Whenever the filter is applied, @func
- * will be called with info about the file to be filtered and @func_data as
+ * will be called with info about the file to be filtered and @funcdata as
  * parameters.  If @func returns %TRUE, the file passes the filter; if it
  * returns %FALSE, it does not.